@@ -26,15 +26,15 @@ use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::Exif;
 
-$VERSION = '1.49';
+$VERSION = '1.50';
 
 sub ProcessFujiDir($$$);
 sub ProcessFaceRec($$$);
 
 # the following RAF version numbers have been tested for writing:
 my %testedRAF = (
-    '0100' => 'E550, E900, F770, S5600, S6000fd, S6500fd, HS10/HS11, HS30, S200EXR, X100, XF1, X-Pro1, X-S1 Ver1.00',
-    '0101' => 'X-E1',
+    '0100' => 'E550, E900, F770, S5600, S6000fd, S6500fd, HS10/HS11, HS30, S200EXR, X100, XF1, X-Pro1, X-S1, XQ2 Ver1.00',
+    '0101' => 'X-E1, X20 Ver1.01',
     '0102' => 'S100FS, X10 Ver1.02',
     '0103' => 'IS Pro Ver1.03',
     '0104' => 'S5Pro Ver1.04',
@@ -42,15 +42,16 @@ my %testedRAF = (
     '0111' => 'S5Pro Ver1.11',
     '0114' => 'S9600 Ver1.00',
     '0159' => 'S2Pro Ver1.00',
+    '0200' => 'X10 Ver2.00',
     '0212' => 'S3Pro Ver2.12',
     '0216' => 'S3Pro Ver2.16', # (NC)
     '0218' => 'S3Pro Ver2.18',
-    '0264' => 'F700  Ver2.00',
+    '0264' => 'F700 Ver2.00',
     '0266' => 'S9500 Ver1.01',
     '0269' => 'S9500 Ver1.02',
     '0271' => 'S3Pro Ver2.71', # UV/IR model?
     '0712' => 'S5000 Ver3.00',
-    '0716' => 'S5000 Ver3.00', # (yes, 2 RAF versions with the same firmware version)
+    '0716' => 'S5000 Ver3.00', # (yes, 2 RAF versions with the same Software version)
 );
 
 my %faceCategories = (
@@ -808,7 +809,7 @@ my %faceCategories = (
     0xf00a => 'BlackLevel', #9
     # 0xf00b ?
     0xf00c => 'WB_GRBLevelsStandard', #9 (GRBXGRBX; X=17 is standard illuminant A, X=21 is D65)
-    0xf00d => 'WB_GRBLevelsDaylight', #9
+    0xf00d => 'WB_GRBLevelsAuto', #9
     0xf00e => 'WB_GRBLevels',
     # 0xf00f ?
 );
